OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Pohrana privremeno nije dostupna",
    "Storage invalid" : "Neispravna pohrana",
    "Unknown error" : "Nepoznata pogreška",
    "All files" : "Sve datoteke",
    "Recent" : "Nedavni",
    "Favorites" : "Favoriti",
    "File could not be found" : "Datoteka nije pronađena",
    "Move or copy" : "Premjesti ili kopiraj",
    "Download" : "Preuzmi",
    "Delete" : "Izbriši",
    "Home" : "Početna",
    "Close" : "Zatvori",
    "Could not create folder \"{dir}\"" : "Nije moguće stvoriti mapu „{dir}”",
    "This will stop your current uploads." : "Ovo će zaustaviti vaše trenutačne otpreme.",
    "Upload cancelled." : "Otpremanje je prekinuto.",
    "Processing files …" : "Obrada datoteka...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nije moguće otpremiti {filename} jer je direktorij ili ima 0 bajta",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedovoljno slobodnog prostora, otpremate {size1} a preostalo je samo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa „{dir}” više ne postoji",
    "Not enough free space" : "Nema dovoljno slobodnog prostora",
    "An unknown error has occurred" : "Došlo je do nepoznate pogreške",
    "Uploading …" : "Otpremanje...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nije podržano otpremanje ove stavke",
    "Target folder does not exist any more" : "Ciljna mapa više ne postoji",
    "Error when assembling chunks, status code {status}" : "Pogreška prilikom sastavljanja komada, šifra statusa {status}",
    "Actions" : "Radnje",
    "Rename" : "Preimenuj",
    "Copy" : "Kopiraj",
    "Choose target folder" : "Odaberi ciljnu mapu",
    "Open" : "Otvori",
    "Delete file" : "Izbriši datoteku",
    "Delete folder" : "Izbriši mapu",
    "Disconnect storage" : "Odspoji pohranu",
    "Unshare" : "Prestani dijeliti",
    "Could not load info for file \"{file}\"" : "Nije moguće učitati podatke za datoteku „{file}”",
    "Files" : "Datoteke",
    "Details" : "Pojedinosti",
    "Select" : "Odaberi",
    "Pending" : "Na čekanju",
    "Unable to determine date" : "Nije moguće odrediti datum",
    "This operation is forbidden" : "Ova radnja je zabranjena",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ovaj direktorij je nedostupan, provjerite zapise ili se obratite administratoru",
    "Could not move \"{file}\", target exists" : "Neuspješno premještanje „{file}”, ciljna datoteka postoji",
    "Could not move \"{file}\"" : "Neuspješno premještanje „{file}”",
    "copy" : "kopiraj",
    "Could not copy \"{file}\", target exists" : "Neuspješno kopiranje „{file}”, ciljna datoteka postoji",
    "Could not copy \"{file}\"" : "Neuspješno kopiranje „{file}”",
    "Copied {origin} inside {destination}" : "Kopirano {origin} unutar {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} i {nbfiles} ostalih datoteka unutar {destination}",
    "{newName} already exists" : "{newName} već postoji",
    "Could not rename \"{fileName}\", it does not exist any more" : "Neuspješno preimenovanje „{fileName}”, datoteka više ne postoji",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Naziv „{targetName}” upotrebljava se u mapi „{dir}”. Odaberite drugi naziv.",
    "Could not rename \"{fileName}\"" : "Neuspješno preimenovanje „{fileName}”",
    "Could not create file \"{file}\"" : "Nije moguće stvoriti datoteku „{file}”",
    "Could not create file \"{file}\" because it already exists" : "Nije moguće stvoriti datoteku „{file}” jer već postoji",
    "Could not create folder \"{dir}\" because it already exists" : "Nije moguće stvoriti mapu „{dir}” jer već postoji",
    "Error deleting file \"{fileName}\"." : "Pogreška pri brisanju datoteke „{fileName}”.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nema rezultata pretraživanja u drugim mapama za {tag}{filter}{endtag}",
    "Name" : "Naziv",
    "Size" : "Veličina",
    "Modified" : "Promijenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapa","%n mapa"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteka","%n datoteka"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["uključujući %n skrivenih","uključujući %n skrivenih","uključujući %n skrivenih"],
    "You don’t have permission to upload or create files here" : "Ovdje ne smijete otpremati ili stvarati datoteke",
    "_Uploading %n file_::_Uploading %n files_" : ["Otpremanje %n datoteku","Prenosim %n datoteka","Prenosim %n datoteka"],
    "New" : "Novo",
    "Select file range" : "Odaberi raspon datoteka",
    "{used} of {quota} used" : "Iskorišteno {used} od {quota}",
    "{used} used" : "Iskorišteno {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan.",
    "\"/\" is not allowed inside a file name." : "„/” nije dopušteno unutar naziva datoteke.",
    "\"{name}\" is not an allowed filetype" : "„{name}” nije dopuštena vrsta datoteke",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Pohrana {owner} je puna, datoteke više nije moguće ažurirati niti sinkronizirati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaša je pohrana puna, datoteke više nije moguće ažurirati ni sinkronizirati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Pohrana {owner} je skoro puna ({usedSpacePercent} %)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaš prostor za pohranu gotovo je pun ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["odgovara '{filter}'","podudaranje '{filter}'","podudaranje '{filter}'"],
    "View in folder" : "Prikaži u mapi",
    "Copied!" : "Kopirano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj izravnu poveznicu (samo za korisnike koji smiju pristupiti ovoj datoteci/mapi)",
    "Path" : "Put",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajtova","%n bajtova"],
    "Favorited" : "Favorit",
    "Favorite" : "Favorit",
    "You can only favorite a single file or folder at a time" : "Istovremeno možete označiti samo jednu datoteku ili mapu kao favorita",
    "New folder" : "Nova mapa",
    "Upload file" : "Otpremi datoteku",
    "Not favorited" : "Nije označeno kao favorit",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "An error occurred while trying to update the tags" : "Došlo je do pogreške prilikom ažuriranja oznaka",
    "Added to favorites" : "Dodano u favorite",
    "Removed from favorites" : "Uklonjeno iz favorita",
    "You added {file} to your favorites" : "Dodali ste {file} u svoje favorite",
    "You removed {file} from your favorites" : "Uklonili ste {file} iz svojih favorita",
    "File changes" : "Promjene datoteka",
    "Created by {user}" : "Stvorio {user}",
    "Changed by {user}" : "Izmijenio {user}",
    "Deleted by {user}" : "Izbrisao {user}",
    "Restored by {user}" : "Vratio {user}",
    "Renamed by {user}" : "Preimenovao {user}",
    "Moved by {user}" : "Premjestio {user}",
    "\"remote user\"" : "„udaljeni korisnik”",
    "You created {file}" : "Stvorili ste {file}",
    "You created an encrypted file in {file}" : "Stvorili ste šifriranu datoteku u {file}",
    "{user} created {file}" : "{user} je stvorio {file}",
    "{user} created an encrypted file in {file}" : "{user} je stvorio šifriranu datoteku u {file}",
    "{file} was created in a public folder" : "{file} je stvorena u javnoj mapi",
    "You changed {file}" : "Promijenili ste {file}",
    "You changed an encrypted file in {file}" : "Promijenili ste šifriranu datoteku u {file}",
    "{user} changed {file}" : "{user} je promijenio {file}",
    "{user} changed an encrypted file in {file}" : "{user} je promijenio šifriranu datoteku u {file}",
    "You deleted {file}" : "Izbrisali ste {file}",
    "You deleted an encrypted file in {file}" : "Izbrisali ste šifriranu datoteku u {file}",
    "{user} deleted {file}" : "{user} je izbrisao {file}",
    "{user} deleted an encrypted file in {file}" : "{user} je izbrisao šifriranu datoteku u {file}",
    "You restored {file}" : "Vratili ste {file}",
    "{user} restored {file}" : "{user} je vratio {file}",
    "You renamed {oldfile} to {newfile}" : "Preimenovali ste {oldfile} u {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} je preimenovao {oldfile} u {newfile}",
    "You moved {oldfile} to {newfile}" : "Premjestili ste {oldfile} u {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} je premjestio {oldfile} u {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je dodana ili uklonjena iz vaših <strong>favorita</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datoteka ili mapa je <strong>promijenjena</strong> ili <strong>preimenovana</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nova datoteka ili nova mapa je <strong>stvorena</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ili mapa je <strong>izbrisana</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ograničite obavijesti o stvaranju i promjenama svojih <strong>favorita</strong> <em>(samo strujanje)</em>",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ili mapa je <strong>vraćena</strong>",
    "Unlimited" : "Neograničeno",
    "Upload (max. %s)" : "Otprema (maks. %s)",
    "Accept" : "Prihvati",
    "Reject" : "Odbij",
    "File Management" : "Upravljanje datotekama",
    "Change" : "Promijeni",
    "%s used" : "Iskorišteno %s",
    "%s%% of %s used" : "Iskorišteno %s%% od %s",
    "%1$s of %2$s used" : "Iskorišteno %1$s od %2$s",
    "Settings" : "Postavke",
    "Show hidden files" : "Prikaz skrivenih datoteka",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Upotrijebite ovu adresu za <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\"> pristupanje svojim datotekama putem WebDAVa</a>",
    "Toggle grid view" : "Uključi/isključi prikaz rešetke",
    "No files in here" : "Nema datoteka",
    "Upload some content or sync with your devices!" : "Otpremite neki sadržaj ili sinkronizirajte sa svojim uređajima!",
    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
    "Select all" : "Odaberi sve",
    "Upload too large" : "Otprema je prevelika",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate otpremiti premašuju maksimalnu veličinu za otpremu datoteka na ovom poslužitelju.",
    "No favorites yet" : "Još nema favorita",
    "Files and folders you mark as favorite will show up here" : "Ovdje će se prikazati datoteke i mape koje označite kao favorite",
    "Tags" : "Oznake",
    "Deleted files" : "Izbrisane datoteke",
    "Shares" : "Dijeljenja",
    "Shared with others" : "Podijeljeno s ostalima",
    "Shared with you" : "Podijeljeno s vama",
    "Shared by link" : "Podijeljeno putem poveznice",
    "Deleted shares" : "Izbrisana dijeljenja",
    "Text file" : "Tekstna datoteka",
    "New text file.txt" : "Nova tekstna datoteka.txt",
    "File handling" : "Obrada datoteke",
    "Maximum upload size" : "Maksimalna veličina otpreme",
    "max. possible: " : "maks. moguća: ",
    "Save" : "Spremi",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Kod PHP-FPM-a potrebno je 5 minuta da se promjene primijene.",
    "Missing permissions to edit from here." : "Nedostaju dopuštenja za uređivanje.",
    "Cancel upload" : "Otkaži otpremanje",
    "%s of %s used" : "Iskorišteno %s od %s",
    "%1$s%% of %2$s used" : "Iskorišteno %1$s%% od %2$s"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
